@@ -24,19 +24,20 @@ SEXP sum2(SEXP x, SEXP idxs, SEXP naRm, SEXP mode) {
 
   /* Argument 'mode': */
   if (!isInteger(mode)) {
-    error("Argument 'mode' must be a single integer.");
+    error("Argument 'mode' must be a single integer");
   }
   mode2 = asInteger(mode);
 
   /* Argument 'idxs': */
   R_xlen_t nidxs;
-  R_xlen_t *cidxs = validateIndices(idxs, nx, 1, &nidxs);
+  int idxsHasNA;
+  R_xlen_t *cidxs = validateIndicesCheckNA(idxs, nx, 1, &nidxs, &idxsHasNA);
 
   /* Dispatch to low-level C function */
   if (isReal(x)) {
-    sum = sum2_dbl(REAL(x), nx, cidxs, nidxs, narm);
+    sum = sum2_dbl(REAL(x), nx, cidxs, nidxs, idxsHasNA, narm);
   } else if (isInteger(x) || isLogical(x)) {
-    sum = sum2_int(INTEGER(x), nx, cidxs, nidxs, narm);
+    sum = sum2_int(INTEGER(x), nx, cidxs, nidxs, idxsHasNA, narm);
   }
 
 
@@ -57,9 +58,9 @@ SEXP sum2(SEXP x, SEXP idxs, SEXP naRm, SEXP mode) {
 
   case 2: /* numeric */
     PROTECT(ans = allocVector(REALSXP, 1));
-    if (sum > DOUBLE_XMAX) {
+    if (sum > DBL_MAX) {
       REAL(ans)[0] = R_PosInf;
-    } else if (sum < -DOUBLE_XMAX) {
+    } else if (sum < -DBL_MAX) {
       REAL(ans)[0] = R_NegInf;
     } else {
       REAL(ans)[0] = sum;
