@@ -31,7 +31,7 @@ for (mode in c("integer", "logical", "double")) {
     if (setDimnames) dimnames(x) <- dimnames
     else dimnames(x) <- NULL
     # Check names attribute
-    for (useNames in c(NA, TRUE, FALSE)) {
+    for (useNames in c(if (!matrixStats:::isUseNamesNADefunct()) NA, TRUE, FALSE)) {
       y0 <- rowSums2_R(x, na.rm = FALSE, useNames = useNames)
       y1 <- rowSums2(x, na.rm = FALSE, useNames = useNames)
       stopifnot(all.equal(y1, y0))
@@ -59,7 +59,7 @@ for (mode in c("integer", "logical", "double")) {
     if (setDimnames) dimnames(x) <- dimnames
     else dimnames(x) <- NULL
     # Check names attribute
-    for (useNames in c(NA, TRUE, FALSE)) {
+    for (useNames in c(if (!matrixStats:::isUseNamesNADefunct()) NA, TRUE, FALSE)) {
       y0 <- rowSums2_R(x, na.rm = FALSE, useNames = useNames)
       y1 <- rowSums2(x, na.rm = FALSE, useNames = useNames)
       stopifnot(all.equal(y1, y0))
@@ -106,7 +106,7 @@ for (mode in c("integer", "logical", "double")) {
     if (setDimnames) dimnames(x) <- dimnames
     else dimnames(x) <- NULL
     # Check names attribute
-    for (useNames in c(NA, TRUE, FALSE)) {
+    for (useNames in c(if (!matrixStats:::isUseNamesNADefunct()) NA, TRUE, FALSE)) {
       y0 <- rowSums2_R(x, na.rm = TRUE, useNames = useNames)
       y1 <- rowSums2(x, na.rm = TRUE, useNames = useNames)
       stopifnot(all.equal(y1, y0))
@@ -130,7 +130,7 @@ for (setDimnames in c(TRUE, FALSE)) {
   if (setDimnames) dimnames(x) <- dimnames
   else dimnames(x) <- NULL
   # Check names attribute
-  for (useNames in c(NA, TRUE, FALSE)) {
+  for (useNames in c(if (!matrixStats:::isUseNamesNADefunct()) NA, TRUE, FALSE)) {
     y0 <- rowSums2_R(x, na.rm = TRUE, useNames = useNames)
     y1 <- rowSums2(x, na.rm = TRUE, useNames = useNames)
     stopifnot(all.equal(y1, y0))
@@ -153,7 +153,7 @@ for (setDimnames in c(TRUE, FALSE)) {
   if (setDimnames) dimnames(x) <- dimnames
   else dimnames(x) <- NULL
   # Check names attribute
-  for (useNames in c(NA, TRUE, FALSE)) {
+  for (useNames in c(if (!matrixStats:::isUseNamesNADefunct()) NA, TRUE, FALSE)) {
     y0 <- rowSums2_R(x, na.rm = FALSE, useNames = useNames)
     y1 <- rowSums2(x, na.rm = FALSE, useNames = useNames)
     stopifnot(all.equal(y1, y0))
@@ -176,7 +176,7 @@ for (setDimnames in c(TRUE, FALSE)) {
   if (setDimnames) dimnames(x) <- dimnames
   else dimnames(x) <- NULL
   # Check names attribute
-  for (useNames in c(NA, TRUE, FALSE)) {
+  for (useNames in c(if (!matrixStats:::isUseNamesNADefunct()) NA, TRUE, FALSE)) {
     y0 <- rowSums2_R(x, na.rm = FALSE, useNames = useNames)
     y1 <- rowSums2(x, na.rm = FALSE, useNames = useNames)
     stopifnot(all.equal(y1, y0))
@@ -202,7 +202,7 @@ for (setDimnames in c(TRUE, FALSE)) {
   if (setDimnames) dimnames(x) <- dimnames
   else dimnames(x) <- NULL
   # Check names attribute
-  for (useNames in c(NA, TRUE, FALSE)) {
+  for (useNames in c(if (!matrixStats:::isUseNamesNADefunct()) NA, TRUE, FALSE)) {
     y0 <- rowSums2_R(x, na.rm = FALSE, useNames = useNames)
     y1 <- rowSums2(x, na.rm = FALSE, useNames = useNames)
     stopifnot(all.equal(y1, y0))
@@ -251,7 +251,7 @@ for (setDimnames in c(TRUE, FALSE)) {
   if (setDimnames) dimnames(x) <- dimnames
   else dimnames(x) <- NULL
   # Check names attribute
-  for (useNames in c(NA, TRUE, FALSE)) {
+  for (useNames in c(if (!matrixStats:::isUseNamesNADefunct()) NA, TRUE, FALSE)) {
     y0 <- rowSums2_R(x, na.rm = FALSE, useNames = useNames)
     y1 <- rowSums2(x, na.rm = FALSE, useNames = useNames)
     stopifnot(all.equal(y1, y0))
